Scriptname CMHBBettingScript extends ObjectReference  
{; This mod was originally made for Oblivion, which carries a bit of a funny design quirk:
; Oblivion is kinda funny in that you cannot deposit gold as a stackable item like you can in Skyrim.
; This means using the strategy of depositing gold into a betting box was not possible... So we would 
; bet something else. Lockpicks were a reasonable proxy as they are universally exchanged among merchants 
; and have no carry weight. Realistically the player should have to buy gambling tickets that you gamble
; with rather than gambling with gold directly, for this reason. Since this mod is being ported for Skyrim,
; we could switch to using Gold directly. But Lockpick betting is funny to me so I'm not sure yet 
; if I'll rewrite this to use Gold or keep it goofy using Lockpicks. We'll see.
; 
; Post-development update: Using Lockpicks is dumb but it's silly, I'ma keep it.
; If you'd like to change it, use Gold001 everywhere Lockpick is mentioned.}


ObjectReference Property CMHBBetBagRef Auto
MiscObject Property Lockpick Auto
Int RunToggleTutorialMsg = 0
Int PlayerHistoricalWinnings = 0
Int PlayerHistoricalLosses = 0
Int HorseChanceToWin = 11
Int BetAmount = 0
Int WonAmount = 0
Message Property CMHBHorsebettingTutorialMsg Auto
Message Property CMHBWonBigAmount Auto
Message Property CMHBWinMsg Auto
Message Property CMHBLossMsg Auto
Message Property CMHBTotalWinLossMsg Auto


Event OnActivate(ObjectReference whomeverActivatedThis)
	; This will toggle the tutorial message on and off until the player has successfully completed one game.
	If PlayerHistoricalWinnings == 0 && PlayerHistoricalLosses == 0 && RunToggleTutorialMsg == 0
		CMHBHorsebettingTutorialMsg.Show()
		RunToggleTutorialMsg = 1
	Else
		RunToggleTutorialMsg = 0
	EndIf
	CMHBBetBagRef.Activate(Game.GetPlayer(), true)  ; Boolean here forces default activation behaviour.
	RegisterForSingleUpdate(0.2)
EndEvent

Event OnUpdate()
	{Register this script for an update every time OnActivate occurs, so we check if the player placed a bet once they close out of the inventory menu. According to the docs, timers don't increment until menus are closed, which makes this a good replacement for Oblivion's GameMode.}
	; If there's nothing in the betting bag, don't gamble.
	BetAmount = CMHBBetBagRef.GetItemCount(Lockpick)
	If BetAmount != 0
		HorseChanceToWin = 11
		Int RandomAmount = Utility.RandomInt(0, 100)
		Float HorseWinPercent = 1.0 / HorseChanceToWin * 100.0  ; Must use Floats in this operation or it'll cast to an Int, causing HorseWinPercent to always be a 0!
		; Did the RandomAmount roll within the chance to win? Must be lower or equal to win!
		If RandomAmount <= Math.Floor(HorseWinPercent)
			; Player has won - multiply their bet.
			WonAmount = HorseChanceToWin * BetAmount
			; Players who are holding a large number of Lockpicks are encouraged to exchange them for Gold.
			If Game.GetPlayer().GetItemCount(Lockpick) > 200
				CMHBWonBigAmount.Show(BetAmount, WonAmount)
			Else
				CMHBWinMsg.Show(BetAmount, WonAmount)
			EndIf
		Else
			; Player did not win.
			WonAmount = 0
			CMHBLossMsg.Show(BetAmount)
		EndIf
		PlayerHistoricalWinnings += WonAmount
		PlayerHistoricalLosses -= BetAmount
		Game.GetPlayer().AddItem(Lockpick, WonAmount, false)
		CMHBBetBagRef.RemoveItem(Lockpick, BetAmount)
		CMHBTotalWinLossMsg.Show(PlayerHistoricalWinnings, PlayerHistoricalLosses)
	EndIf
EndEvent